#
# spec file for package MotionBox
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           MotionBox
Version:        1.6.0
Release:        lp152.1.5
Summary:        Qt based network video browser
License:        GPL-3.0-only
URL:            http://omega.gg/MotionBox
Source0:        https://github.com/omega-gg/MotionBox/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/omega-gg/Sky/archive/%{version}.tar.gz#/Sky-%{version}.tar.gz
# PATCH-FIX-OPENSUSE MotionBox-1.6.0-private_headers.patch
Patch0:         MotionBox-1.6.0-private_headers.patch
# PATCH-FIX-OPENSUSE MotionBox-1.6.0-paths.patch
Patch1:         MotionBox-1.6.0-paths.patch
# PATCH-FIX-OPENSUSE SKy-1.5.0-soname.patch
Patch2:         Sky-1.6.0-soname.patch
# PATCH-FEATURE-OPENSUSE Sky-1.6.0-use_system_glext.patch
Patch3:         Sky-1.6.0-use_system_glext.patch
# PATCH-FIX-UPSTREAM Sky-1.6.0-libtorrent_1_2.patch aloisio@gmx.com -- do not use -std=c++-11 when building sktorrent module
Patch4:         MotionBox-1.6.0-libtorrent_1_2.patch
# PATCH-FEATURE-OPENSUSE MotionBox-1.6.0-use_system_quazip.patch aloisio@gmx.com -- use system quazip if available
Patch5:         MotionBox-1.6.0-use_system_quazip.patch
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libboost_chrono-devel
BuildRequires:  libboost_random-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  libqt5-qtdeclarative-private-headers-devel
BuildRequires:  update-desktop-files
BuildRequires:  vlc-devel
BuildRequires:  wt-devel
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
BuildRequires:  pkgconfig(libtorrent-rasterbar)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200
BuildRequires:  pkgconfig(quazip)
%endif
Requires:       vlc
ExclusiveArch:  %ix86 x86_64

%description
A network video browser based on Qt.
It streams Torrents, Youtube, Dailymotion, Vimeo and SoundCloud.

%prep
%autosetup -a 1 -p1
mv Sky-%{version} Sky

%build
pushd Sky
%qmake5
make %{?_smp_mflags}
popd
pushd dist
sh ./qrc.sh qt5 linux deploy
popd
%qmake5
make %{?_smp_mflags}

%install
mkdir -pv %{buildroot}/%{_bindir} %{buildroot}%{_libdir} %{buildroot}/%{_datadir}/pixmaps
install -m0755 latest/%{name} %{buildroot}/%{_bindir}
install -m0755 Sky/latest/libSkBackend.so Sky/latest/libSkCore.so \
               Sky/latest/libSkGui.so Sky/latest/libSkMedia.so \
               Sky/latest/libSkTorrent.so -t %{buildroot}%{_libdir}
install -Tm0644 content/pictures/icons/icon.svg %{buildroot}%{_datadir}/pixmaps/%{name}.svg
%suse_update_desktop_file -c %{name} %{name} 'Online video player' %{name} %{name} AudioVideo Video Player

%files
%doc README.md
%license LICENSE.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.svg
%{_libdir}/libSkBackend.so
%{_libdir}/libSkCore.so
%{_libdir}/libSkGui.so
%{_libdir}/libSkMedia.so
%{_libdir}/libSkTorrent.so

%changelog
* Wed Jan 15 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.6.0
  Global:
  * Rename 'The Video Browser' to 'Video Browser'.
  C++:
  * ControllerCore: Add 'updateBackends' and 'resetBackends'
    functions.
  * ControllerCore: Update 'pathCover' for backends.
  * ControllerCore: Update the 'deleteBrowse' function.
  * ControllerCore: Update data format.
  * ControllerCore: Fix the 'applyTorrentOptions' function.
  * DataLocal: Update 'torrent cache' to 2000 megabytes by
    default.
  QML:
  * Create PageSettingsVideo and PageConsole.
  * Remove PanelCover.
  * Add 'bold' style.
  * Add 'ratio' support.
  * Fix 'toolTip' icon scaling.
  * Create 'PageSubtitles(s)'.
  * Rename 'PanelShare' to 'PanelGet'.
  * Gui: Check hover in the 'onIdleChanged' event.
  * Gui: Fix the automatic selection in the 'onDragEnded' event.
  * Gui: Remove 'keepState' in the 'applyProxy' function.
  * Gui: Remove the 'openFolder' function.
  * PanelBrowse: Update to LineEditBoxClear.
  * PanelBrowse: Update 'scrollBrowse' press event.
  * PanelSettings: Add 'autoPlay' button.
  * PanelSettings: Update 'quality' implementation.
  * PanelSettings: Fix 'buttonRepeat' highlight.
  * PanelTracks: No longer change 'PanelAdd' selection when
    clicking on 'buttonBrowse'.
  * BarWindowApplication: Add 'toggleTouch' on ViewDrag.
  * BarWindowApplication: Update 'pOpenTabPlaylist' function.
  * List(s): Fix the 'pRestoreScroll' function.
  * List(s): Fix the 'pDragCheck' function.
  * PageSettingsMain: Add the 'pApplyScale' function.
  * PageSettingsVideo: Fix 'elide' behavior.
- Replaced Sky-1.5.0-private_headers.patch,
  MotionBox-1.5.0-paths.patch, Sky-1.5.0-soname.patch,
  Sky-1.5.0-use_system_glext.patch and
  Sky-1.5.0-libtorrent_1_2.patch with
  MotionBox-1.6.0-private_headers.patch,
  MotionBox-1.6.0-paths.patch, Sky-1.6.0-soname.patch,
  Sky-1.6.0-use_system_glext.patch and
  MotionBox-1.6.0-libtorrent_1_2.patch respectively
- Added MotionBox-1.6.0-use_system_quazip.patch
* Sat Dec  7 2019 Luigi Baldoni <aloisio@gmx.com>
- Add Sky-1.5.0-libtorrent_1_2.patch
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat Mar 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.5.0
  Overview
  * Add light themes.
  * Support the 64 bit architecture by default.
  * Add feeds and tracks history.
  C++
  * DataOnline: Update the 'ONLINE_PATH' variable.
  QML
  * Create PanelDiscover.
  * Create ComponentDiscover.
  * Remove ButtonLogoBorders.
  Other
  * Gui: Update track selection when player stops.
  * Gui: Update tab behavior.
  * Gui: Update the 'pRestoreMiniA' function.
  * Gui: Fix 'play(s)' functions.
  * Gui: Fix the 'openSource' function.
  * Gui: Remove the 'openFolder' function.
  * Splash: Update implementation.
  * BarWindowApplication: Add 'onBefore(s)' functions.
  * BarWindowApplication: Add 'pRestoreMaximize' function.
  * BarTop: Add the 'discover' button.
  * BarTop: Add the 'playlist' property.
  * PanelApplication: Update page buttons.
  * PanelSearch: Start the search when you click a backend.
  * PanelAdd: Fix the 'maximum height' property.
  * LineEditSearch: Update the 'default text' behavior.
  * ListFolder: Fix the 'folder' events.
  Style
  * Enable 'light' design by default.
  Changes for Sky kit 1.5.0:
  Qt
  * Change QUrl(s) to QString(s) to improve comparisons.
  SkCore
  * WControllerFile: Add the 'folderUrl' function.
  * WControllerFile: Update the 'toLocal, toString' functions.
  * WControllerFile: Fix the 'file url' functions.
  * WControllerFile: Fix the 'toLocalFile' function.
  * WControllerScript: Add 'QJSEngine' implementation.
  * WRemoteTimeout: Fix the 'timeout' function.
  SkGui
  * WControllerPlaylist: Update the 'query' implementation.
  * WControllerPlaylist: Fix the 'loaded' function.
  * WControllerPlaylistData: Update the 'applyHtml' function.
  * WAbstractView: Add the 'on close' function.
  * WAbstractView: Update the 'task bar' workaround.
  * WView: Add the 'on close' function.
  * WView: Fix the 'update flags' function.
  * WDeclarativeImageBase: Fix the 'set filter' function.
  * WDeclarativeImageBase: Fix the 'onFilterUpdated' function.
  * WDeclarativeImage(s): Fix the 'scale' implementation.
  * WDeclarativeTextSvg: Fix the 'get width' implementation.
  * WPlaylist: Add the 'move(s)' functions.
  SkMedia
  * WBackendVlc: Update the shaders implementation.
  * WVlcEngine: Add the 'avcodec-fast' option.
  SkTorrent
  * Update implementation to the 1.2.0 API.
  * WHookTorrent: Update the 'skip' behavior for 'avi' files.
  * WHookTorrent: Fix the 'read' function.
  * WBackendTorrent: Update the 'sort' implementation.
  * WTorrentEngine: Update torrent settings.
  * WTorrentEngine: Add the 'get index' function.
  * WTorrentEngine: Fix the 'remove' function.
  * WTorrentEngine: Fix the 'select file ' function.
  * WTorrentEngine: Fix the 'handle id' variables.
  SkyComponents
  * Create ItemWipe(s).
  * Rename ScrollAreaVertical to ScrollArea.
  * Rename ScrollBarVertical to ScrollBar.
  * Rename ContextualComponent to ComponentContextual.
  * Remove SizeHint.
  * PanelImage: Add the 'image background' alias.
  * ScrollBar: Remove buttons.
  * SliderStream: Update the 'left' button.
  * TabsBrowser: Add 'onBefore(s)' functions.
  * WallVideo: Update the 'player back' item.
  * WallVideo: Update the 'cover' behavior.
  * ComponentTabBrowser, ComponentWallBookmarkTrack: Update the
    'icon' source and caching.
  SkyPresentation
  * BaseLogo: Update to 'flat' design.
  Style
  * Add 'night' design.
  * Add 'light' design.
  * Enable 'light' design by default.
- Refreshed Sky-1.4.0-private_headers.patch as
  Sky-1.5.0-private_headers.patch, MotionBox-1.4.0-paths.patch
  as MotionBox-1.5.0-paths.patch, Sky-1.4.0-soname.patch as
  Sky-1.5.0-soname.patch and Sky-1.4.0-use_system_glext.patch
  as Sky-1.5.0-use_system_glext.patch
- Dropped Sky-1.4.0-fix_youtube_extract_source.patch and
  Sky-1.4.0-fix_youtube_extract_source_2.patch (no longer
  necessary)
* Tue Oct  9 2018 Luigi Baldoni <aloisio@gmx.com>
- Fixed runtime requirements
* Fri Oct  5 2018 Luigi Baldoni <aloisio@gmx.com>
- Initial package (v 1.4.0)
